@@ -1,16 +1,26 @@
 {-# LANGUAGE DeriveFunctor #-}
+
+{-# LANGUAGE CPP #-}
+#if MIN_VERSION_base(4,8,1)
+#define HAS_SOURCE_LOCATIONS
+{-# LANGUAGE ImplicitParams #-}
+#endif
+
 -- |
 -- Stability: unstable
 module Test.Hspec.Core.Tree (
   SpecTree
 , Tree (..)
 , Item (..)
-, Location (..)
-, LocationAccuracy (..)
 , specGroup
 , specItem
 ) where
 
+#ifdef HAS_SOURCE_LOCATIONS
+import           GHC.SrcLoc
+import           GHC.Stack
+#endif
+
 import           Prelude ()
 import           Test.Hspec.Compat
 
@@ -67,23 +77,6 @@ data Item a = Item {
 , itemExample :: Params -> (ActionWith a -> IO ()) -> ProgressCallback -> IO Result
 }
 
--- | @Location@ is used to represent source locations.
-data Location = Location {
-  locationFile :: String
-, locationLine :: Int
-, locationColumn :: Int
-, locationAccuracy :: LocationAccuracy
-} deriving (Eq, Show)
-
--- | A marker for source locations
-data LocationAccuracy =
-  -- | The source location is accurate
-  ExactLocation |
-  -- | The source location was determined on a best-effort basis and my be
-  -- wrong or inaccurate
-  BestEffort
-  deriving (Eq, Show)
-
 -- | The @specGroup@ function combines a list of specs into a larger spec.
 specGroup :: String -> [SpecTree a] -> SpecTree a
 specGroup s = Node msg
@@ -93,9 +86,22 @@ specGroup s = Node msg
       | otherwise = s
 
 -- | The @specItem@ function creates a spec item.
+#ifdef HAS_SOURCE_LOCATIONS
+specItem :: (?loc :: CallStack, Example a) => String -> a -> SpecTree (Arg a)
+#else
 specItem :: Example a => String -> a -> SpecTree (Arg a)
-specItem s e = Leaf $ Item requirement Nothing False (evaluateExample e)
+#endif
+specItem s e = Leaf $ Item requirement location False (evaluateExample e)
   where
     requirement
       | null s = "(unspecified behavior)"
       | otherwise = s
+
+    location :: Maybe Location
+#ifdef HAS_SOURCE_LOCATIONS
+    location = case reverse (getCallStack ?loc) of
+      (_, loc) : _ -> Just (Location (srcLocFile loc) (srcLocStartLine loc) (srcLocStartCol loc) ExactLocation)
+      _ -> Nothing
+#else
+    location = Nothing
+#endif
