@@ -14,10 +14,9 @@ module Helper (
 , ignoreUserInterrupt
 , throwException
 
-, shouldStartWith
-, shouldEndWith
-
 , shouldUseArgs
+
+, removeLocations
 ) where
 
 import           Prelude ()
@@ -53,12 +52,6 @@ ignoreUserInterrupt action = E.catchJust (guard . (== E.UserInterrupt)) action r
 captureLines :: IO a -> IO [String]
 captureLines = fmap lines . capture_
 
-shouldStartWith :: (Eq a, Show a) => [a] -> [a] -> Expectation
-x `shouldStartWith` y = x `shouldSatisfy` isPrefixOf y
-
-shouldEndWith :: (Eq a, Show a) => [a] -> [a] -> Expectation
-x `shouldEndWith` y = x `shouldSatisfy` isSuffixOf y
-
 -- replace times in summary with zeroes
 normalizeSummary :: [String] -> [String]
 normalizeSummary = map f
@@ -88,3 +81,6 @@ shouldUseArgs args p = do
         H.it "foo" False
   (silence . ignoreExitCode . withArgs args . H.hspec) spec
   readIORef spy >>= (`shouldSatisfy` p)
+
+removeLocations :: H.SpecWith a -> H.SpecWith a
+removeLocations = H.mapSpecItem_ (\item -> item{H.itemLocation = Nothing})
