@@ -26,7 +26,7 @@ spec = do
         evaluateExample True `shouldReturn` H.Success
 
       it "returns Fail on False" $ do
-        evaluateExample False `shouldReturn` H.Fail ""
+        evaluateExample False `shouldReturn` H.Fail Nothing ""
 
       it "propagates exceptions" $ do
         evaluateExample (error "foobar" :: Bool) `shouldThrow` errorCall "foobar"
@@ -36,7 +36,8 @@ spec = do
         evaluateExample (23 `shouldBe` (23 :: Int)) `shouldReturn` H.Success
 
       it "returns Fail if an expectation does not hold" $ do
-        evaluateExample (23 `shouldBe` (42 :: Int)) `shouldReturn` H.Fail "expected: 42\n but got: 23"
+        H.Fail _ msg <- evaluateExample (23 `shouldBe` (42 :: Int))
+        msg `shouldEndWith` "expected: 42\n but got: 23"
 
       it "propagates exceptions" $ do
         evaluateExample (error "foobar" :: Expectation) `shouldThrow` errorCall "foobar"
@@ -65,11 +66,11 @@ spec = do
         evaluateExample (property $ \n -> n == (n :: Int)) `shouldReturn` H.Success
 
       it "returns Fail if property does not hold" $ do
-        H.Fail _ <- evaluateExample $ property $ \n -> n /= (n :: Int)
+        H.Fail _ _ <- evaluateExample $ property $ \n -> n /= (n :: Int)
         return ()
 
       it "shows what falsified it" $ do
-        H.Fail r <- evaluateExample $ property $ \ (x :: Int) (y :: Int) -> (x == 0 && y == 1) ==> False
+        H.Fail _ r <- evaluateExample $ property $ \ (x :: Int) (y :: Int) -> (x == 0 && y == 1) ==> False
         r `shouldBe` intercalate "\n"  [
             "Falsifiable (after 1 test): "
           , "0"
@@ -88,7 +89,7 @@ spec = do
         readIORef ref `shouldReturn` 2000
 
       it "pretty-prints exceptions" $ do
-        H.Fail r <- evaluateExample $ property (\ (x :: Int) -> (x == 0) ==> (error "foobar" :: Bool))
+        H.Fail _ r <- evaluateExample $ property (\ (x :: Int) -> (x == 0) ==> (error "foobar" :: Bool))
         r `shouldBe` intercalate "\n" [
 #if MIN_VERSION_QuickCheck(2,7,0)
             "uncaught exception: ErrorCall (foobar) (after 1 test)"
@@ -100,10 +101,10 @@ spec = do
 
       context "when used with shouldBe" $ do
         it "shows what falsified it" $ do
-          H.Fail r <- evaluateExample $ property $ \ (x :: Int) (y :: Int) -> (x == 0 && y == 1) ==> 23 `shouldBe` (42 :: Int)
-          r `shouldBe` intercalate "\n" [
-              "Falsifiable (after 1 test): "
-            , "expected: 42"
+          H.Fail _ r <- evaluateExample $ property $ \ (x :: Int) (y :: Int) -> (x == 0 && y == 1) ==> 23 `shouldBe` (42 :: Int)
+          r `shouldStartWith` "Falsifiable (after 1 test): \n"
+          r `shouldEndWith` intercalate "\n" [
+              "expected: 42"
             , " but got: 23"
             , "0"
             , "1"
